@@ -189,11 +189,13 @@ sub needs_horde_objects {
 }
 
 sub needs_horde_misc {
+    need_file( 'wrap_message.func',                 'Message wrapping function.' );
+    need_file( 'textwrap.func',                     'textwrap function' );
     need_file( 'set_env_in_string.func',            'set env in a string');
-    need_file(' mailfrom.func',                     'interface to send mail');
-   need_file( 'status.func',                       'status function' );
-   need_file( 'include_lynx_menu.func',            'include_lynx_menu' );
-   need_file( 'caching_headers.func',           'Cache Control Commands' );
+    need_file( 'mailfrom.func',                     'interface to send mail');
+    need_file( 'status.func',                       'status function' );
+    need_file( 'include_lynx_menu.func',            'include_lynx_menu' );
+    need_file( 'caching_headers.func',           'Cache Control Commands' );
 }
 
 sub needs_horde_language {
